==> ala-2.3.1-en-download.zip: ala-2.3.1-en/webhelp/ala-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasauditing
//
//	Copyright (c) 2016-2024 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasauditing = {
    baseurls: ["../"],
    varname: "adabasauditing",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes" },
            { url: "intro/co_intro.htm", title: "Introducing Adabas Auditing on Mainframe",
              tree: [
                  { url: "intro/co_conc.htm", title: "Concepts" },
              ]
            },
            { url: "install/ig_overview.htm", title: "Installation",
              tree: [
                  { url: "install/ig_req.htm", title: "System Requirements" },
                  { url: "install/ig_tape.htm", title: "About the Installation Tape" },
                  { url: "install/ig_zos.htm", title: "Installation for z/OS" },
                  { url: "install/ig_osmf.htm", title: "Installation for z/OS using z/OSMF Workflows" },
                  { url: "install/ig_files.htm", title: "Activating Auditing for Application Files" },
                  { url: "install/ig_tp.htm", title: "Activating Auditing for TP Monitors" },
                  { url: "install/ig_LUW.htm", title: "Activating Auditing for LUW applications" },
              ]
            },
            { url: "config/conf_overview.htm", title: "Adabas Auditing Configuration (SYSALA)",
              tree: [
                  { url: "config/conf_conf.htm", title: "Adabas Auditing Configuration Overview" },
                  { url: "config/conf_dest.htm", title: "Maintaining Destination Definitions" },
                  { url: "config/conf_filter.htm", title: "Maintaining Filter Definitions" },
                  { url: "config/conf_format.htm", title: "Maintaining Format Buffer Definitions" },
                  { url: "config/conf_sub.htm", title: "Maintaining Subscription Definitions" },
                  { url: "config/conf_admsub.htm", title: "Maintaining Admin Subscription Definitions" },
                  { url: "config/conf_global.htm", title: "Maintaining Global Definitions" },
                  { url: "config/conf_lfile.htm", title: "Maintaining LFILE Parameters" },
              ]
            },
            { url: "admin/ag_overview.htm", title: "Adabas Auditing Administration (SYSALAA)",
              tree: [
                  { url: "admin/ag_intro.htm", title: "Adabas Auditing Administration Overview" },
                  { url: "admin/ag_srvr.htm", title: "Audit Server Administration" },
                  { url: "admin/ag_nucl.htm", title: "Nucleus Audit Administration" },
              ]
            },
            { url: "operations/og_overview.htm", title: "Operations",
              tree: [
                  { url: "operations/og_slog.htm", title: "Using the Auditing Subscription Logging (SLOG) Facility" },
                  { url: "operations/og_aos.htm", title: "AOS Features Supporting Adabas Auditing" },
              ]
            },
            { url: "aav/aav.htm", title: "Adabas Audit Data Viewer",
              tree: [
                  { url: "aav/aav_introduction.htm", title: "Introduction" },
                  { url: "aav/aav_installation.htm", title: "Installation" },
                  { url: "aav/aav_login.htm", title: "Login" },
                  { url: "aav/aav_user_profile.htm", title: "User Profile" },
                  { url: "aav/aav_layouts.htm", title: "Layouts" },
                  { url: "aav/aav_logs_searching.htm", title: "Logs Searching" },
                  { url: "aav/aav_scheduled_reports.htm", title: "Scheduled Reports" },
                  { url: "aav/aav_error_messages.htm", title: "Error Messages" },
              ]
            },
            { url: "aar_sp_req/co_aar_sp_req.htm", title: "Audit Data Retrieval" },
            { url: "reference/ref_overview.htm", title: "Adabas Auditing Reference",
              tree: [
                  { url: "reference/ref_initial.htm", title: "Audit Server Initialization Parameters" },
                  { url: "reference/ref_nucleus.htm", title: "Adabas Nucleus Auditing Parameters (ADAANP)" },
                  { url: "reference/ref_audit.htm", title: "Pertinent ADARUN Parameters for Auditing" },
                  { url: "reference/ref_subsc.htm", title: "Pertinent ADARUN Parameters for Auditing with Subscription Logging" },
                  { url: "reference/ref_operate.htm", title: "Pertinent Operator Commands for Auditing" },
                  { url: "reference/ref_utilities.htm", title: "Utilities Used with Adabas Auditing" },
              ]
            },
            { url: "messages/ala_messages.htm", title: "Messages and Codes",
              tree: [
                  { url: "messages/messages_startrun.htm", title: "Adabas Nucleus Auditing Start-up and Run-time Messages" },
                  { url: "messages/ADAA.htm", title: "ADAA* Auditing Messages" },
                  { url: "messages/messages_utility.htm", title: "ADADBS Utility Messages" },
                  { url: "messages/messages_response.htm", title: "Adabas Response Codes" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasauditing });

==> ala-2.3.2-en-download.zip: ala-2.3.2-en/webhelp/ala-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasauditing
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasauditing = {
    baseurls: ["../"],
    varname: "adabasauditing",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes" },
            { url: "intro/co_intro.htm", title: "Introducing Adabas Auditing on Mainframe",
              tree: [
                  { url: "intro/co_conc.htm", title: "Concepts" },
              ]
            },
            { url: "install/ig_overview.htm", title: "Installation",
              tree: [
                  { url: "install/ig_req.htm", title: "System Requirements" },
                  { url: "install/ig_tape.htm", title: "About the Installation Tape" },
                  { url: "install/ig_zos.htm", title: "Installation for z/OS" },
                  { url: "install/ig_files.htm", title: "Activating Auditing for Application Files" },
                  { url: "install/ig_tp.htm", title: "Activating Auditing for TP Monitors" },
                  { url: "install/ig_LUW.htm", title: "Activating Auditing for LUW applications" },
              ]
            },
            { url: "config/conf_overview.htm", title: "Adabas Auditing Configuration (SYSALA)",
              tree: [
                  { url: "config/conf_conf.htm", title: "Adabas Auditing Configuration Overview" },
                  { url: "config/conf_dest.htm", title: "Maintaining Destination Definitions" },
                  { url: "config/conf_filter.htm", title: "Maintaining Filter Definitions" },
                  { url: "config/conf_format.htm", title: "Maintaining File Schema Definitions" },
                  { url: "config/conf_sub.htm", title: "Maintaining Subscription Definitions" },
                  { url: "config/conf_admsub.htm", title: "Maintaining Admin Subscription Definitions" },
                  { url: "config/conf_global.htm", title: "Maintaining Global Definitions" },
                  { url: "config/conf_lfile.htm", title: "Maintaining LFILE Parameters" },
              ]
            },
            { url: "admin/ag_overview.htm", title: "Adabas Auditing Administration (SYSALAA)",
              tree: [
                  { url: "admin/ag_intro.htm", title: "Adabas Auditing Administration Overview" },
                  { url: "admin/ag_srvr.htm", title: "Audit Server Administration" },
                  { url: "admin/ag_nucl.htm", title: "Nucleus Audit Administration" },
              ]
            },
            { url: "operations/og_overview.htm", title: "Operations",
              tree: [
                  { url: "operations/og_slog.htm", title: "Using the Auditing Subscription Logging (SLOG) Facility" },
                  { url: "operations/og_aos.htm", title: "AOS Features Supporting Adabas Auditing" },
              ]
            },
            { url: "aav/aav.htm", title: "Adabas Audit Data Viewer",
              tree: [
                  { url: "aav/aav_introduction.htm", title: "Introduction" },
                  { url: "aav/aav_installation.htm", title: "Installation" },
                  { url: "aav/aav_login.htm", title: "Login" },
                  { url: "aav/aav_user_profile.htm", title: "User Profile" },
                  { url: "aav/aav_layouts.htm", title: "Layouts" },
                  { url: "aav/aav_logs_searching.htm", title: "Logs Searching" },
                  { url: "aav/aav_scheduled_reports.htm", title: "Scheduled Reports" },
                  { url: "aav/aav_error_messages.htm", title: "Error Messages" },
              ]
            },
            { url: "aar_sp_req/co_aar_sp_req.htm", title: "Audit Data Retrieval" },
            { url: "reference/ref_overview.htm", title: "Adabas Auditing Reference",
              tree: [
                  { url: "reference/ref_initial.htm", title: "Audit Server Initialization Parameters" },
                  { url: "reference/ref_nucleus.htm", title: "Adabas Nucleus Auditing Parameters (ADAANP)" },
                  { url: "reference/ref_audit.htm", title: "Pertinent ADARUN Parameters for Auditing" },
                  { url: "reference/ref_subsc.htm", title: "Pertinent ADARUN Parameters for Auditing with Subscription Logging" },
                  { url: "reference/ref_operate.htm", title: "Pertinent Operator Commands for Auditing" },
                  { url: "reference/ref_utilities.htm", title: "Utilities Used with Adabas Auditing" },
                  { url: "reference/ref_cor.htm", title: "Auditing the Adabas System Coordinator Configuration, Security, and Natural Files" },
              ]
            },
            { url: "messages/ala_messages.htm", title: "Messages and Codes",
              tree: [
                  { url: "messages/messages_startrun.htm", title: "Adabas Nucleus Auditing Start-up and Run-time Messages" },
                  { url: "messages/ADAA.htm", title: "ADAA* Auditing Messages" },
                  { url: "messages/messages_utility.htm", title: "ADADBS Utility Messages" },
                  { url: "messages/messages_response.htm", title: "Adabas Response Codes" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasauditing });
